g++ -fPIC -shared -o libdeps6.so -DNAME=\"6\" deps.cpp
g++ -L. -fPIC -shared -o libdeps5.so -ldeps6 -DNAME=\"5\" deps.cpp
g++ -L. -fPIC -shared -o libdeps4.so -ldeps5 -DNAME=\"4\" deps.cpp
g++ -L. -fPIC -shared -o libdeps3.so -ldeps4 -DNAME=\"3\" deps.cpp
g++ -L. -fPIC -shared -o libdeps2.so -ldeps3 -DNAME=\"2\" deps.cpp
g++ -L. -fPIC -shared -o libdeps1.so -ldeps2 -DNAME=\"1\" deps.cpp
g++ -Wl,-rpath -Wl,/tmp -L. -o main -ldeps6 -ldeps5 -ldeps4 -ldeps3 -ldeps2 -ldeps1 -DMAIN deps.cpp

